componenttools.partition_components_once_by_prolated_durations_ge_with_overhang
===============================================================================

.. autofunction:: abjad.tools.componenttools.partition_components_once_by_prolated_durations_ge_with_overhang
